@@ -292,7 +292,6 @@ file_transfer_dialog_init (FileTransferDialog *dlg)
 	GtkWidget *vbox;
 	GtkWidget *hbox;
 	GtkWidget *progress_vbox;
-	GtkWidget *table;
 	char      *markup;
 	GtkWidget *content_area;
 
@@ -305,11 +304,7 @@ file_transfer_dialog_init (FileTransferDialog *dlg)
 
 	gtk_widget_set_size_request (GTK_WIDGET (dlg), 350, -1);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
-#else
-	vbox = gtk_vbox_new (FALSE, 6);
-#endif
 	gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
 	gtk_box_pack_start (GTK_BOX (content_area), vbox, TRUE, TRUE, 0);
 
@@ -327,23 +322,10 @@ file_transfer_dialog_init (FileTransferDialog *dlg)
 
 	gtk_box_pack_start (GTK_BOX (vbox), dlg->priv->status, FALSE, FALSE, 0);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-#else
-	hbox = gtk_hbox_new (FALSE, 0);
-#endif
 	gtk_box_pack_start (GTK_BOX (vbox), hbox, TRUE, TRUE, 0);
 
-	table = gtk_table_new (2, 2, FALSE);
-	gtk_table_set_row_spacings (GTK_TABLE (table), 4);
-	gtk_table_set_col_spacings (GTK_TABLE (table), 4);
-
-	gtk_box_pack_start (GTK_BOX (vbox), GTK_WIDGET (table), FALSE, FALSE, 0);
-#if GTK_CHECK_VERSION (3, 0, 0)
 	progress_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-#else
-	progress_vbox = gtk_vbox_new (TRUE, 0);
-#endif
 	gtk_box_pack_start (GTK_BOX (vbox), progress_vbox, FALSE, FALSE, 0);
 
 	dlg->priv->progress = gtk_progress_bar_new ();
@@ -406,9 +388,7 @@ file_transfer_job_progress (goffset current_bytes,
 	data->current_bytes = current_bytes;
 	data->total_bytes = total_bytes;
 
-	gdk_threads_enter ();
 	file_transfer_job_update (data);
-	gdk_threads_leave ();
 }
 
 static void
