@@ -369,40 +369,22 @@ main (int argc, char **argv)
 
     nb = gtk_notebook_new ();
 
-#if GTK_CHECK_VERSION (3, 0, 0)
     general_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     behaviour_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     placement_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-#else
-    general_vbox = gtk_vbox_new (FALSE, 0);
-    behaviour_vbox = gtk_vbox_new (FALSE, 0);
-    placement_vbox = gtk_vbox_new (FALSE, 0);
-#endif
 
     widget = gtk_label_new (_("General"));
-#if GTK_CHECK_VERSION (3, 0, 0)
     hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-#else
-    hbox = gtk_hbox_new (FALSE, 0);
-#endif
     gtk_box_pack_start (GTK_BOX (hbox), general_vbox, FALSE, FALSE, 6);
     gtk_notebook_append_page (GTK_NOTEBOOK (nb), hbox, widget);
 
     widget = gtk_label_new (_("Behaviour"));
-#if GTK_CHECK_VERSION (3, 0, 0)
     hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-#else
-    hbox = gtk_hbox_new (FALSE, 0);
-#endif
     gtk_box_pack_start (GTK_BOX (hbox), behaviour_vbox, FALSE, FALSE, 6);
     gtk_notebook_append_page (GTK_NOTEBOOK (nb), hbox, widget);
 
     widget = gtk_label_new (_("Placement"));
-#if GTK_CHECK_VERSION (3, 0, 0)
     hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-#else
-    hbox = gtk_hbox_new (FALSE, 0);
-#endif
     gtk_box_pack_start (GTK_BOX (hbox), placement_vbox, FALSE, FALSE, 6);
     gtk_notebook_append_page (GTK_NOTEBOOK (nb), hbox, widget);
 
@@ -410,15 +392,10 @@ main (int argc, char **argv)
     widget = title_label_new (N_("Compositing Manager"));
     gtk_box_pack_start (GTK_BOX (general_vbox), widget, FALSE, FALSE, 6);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
     vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
     hbox1 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-#else
-    vbox = gtk_vbox_new (FALSE, 0);
-    hbox = gtk_hbox_new (FALSE, 0);
-    hbox1 = gtk_hbox_new (FALSE, 0);
-#endif
+
     compositing_checkbutton = gtk_check_button_new_with_mnemonic (_("Enable software _compositing window manager"));
     compositing_fast_alt_tab_checkbutton = gtk_check_button_new_with_mnemonic (_("Disable _thumbnails in Alt-Tab"));
     gtk_box_pack_start (GTK_BOX (vbox), compositing_checkbutton, FALSE, FALSE, 6);
@@ -431,11 +408,7 @@ main (int argc, char **argv)
     widget = title_label_new (N_("Titlebar Buttons"));
     gtk_box_pack_start (GTK_BOX (general_vbox), widget, FALSE, FALSE, 6);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
     hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-#else
-    hbox = gtk_hbox_new (FALSE, 0);
-#endif
     widget = gtk_label_new (_("Position:"));
     gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 6);
     titlebar_layout_optionmenu = gtk_combo_box_text_new ();
@@ -446,11 +419,7 @@ main (int argc, char **argv)
     widget = title_label_new (N_("New Windows"));
     gtk_box_pack_start (GTK_BOX (placement_vbox), widget, FALSE, FALSE, 6);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
     hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-#else
-    hbox = gtk_hbox_new (FALSE, 0);
-#endif
     center_new_windows_checkbutton = gtk_check_button_new_with_mnemonic (_("Center _new windows"));
     gtk_box_pack_start (GTK_BOX (hbox), center_new_windows_checkbutton, FALSE, FALSE, 6);
     gtk_box_pack_start (GTK_BOX (placement_vbox), hbox, FALSE, FALSE, 6);
@@ -459,11 +428,7 @@ main (int argc, char **argv)
     widget = title_label_new (N_("Window Snapping"));
     gtk_box_pack_start (GTK_BOX (placement_vbox), widget, FALSE, FALSE, 6);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
     hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-#else
-    hbox = gtk_hbox_new (FALSE, 0);
-#endif
     side_by_side_tiling_checkbutton = gtk_check_button_new_with_mnemonic (_("Enable side by side _tiling"));
     gtk_box_pack_start (GTK_BOX (hbox), side_by_side_tiling_checkbutton, FALSE, FALSE, 6);
     gtk_box_pack_start (GTK_BOX (placement_vbox), hbox, FALSE, FALSE, 6);
@@ -472,22 +437,12 @@ main (int argc, char **argv)
     widget = title_label_new (N_("Window Selection"));
     gtk_box_pack_start (GTK_BOX (behaviour_vbox), widget, FALSE, FALSE, 6);
 
-
-#if GTK_CHECK_VERSION (3, 0, 0)
     vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     vbox1 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
     hbox1 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
     hbox2 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
     hbox3 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-#else
-    vbox = gtk_vbox_new (FALSE, 0);
-    vbox1 = gtk_vbox_new (FALSE, 0);
-    hbox = gtk_hbox_new (FALSE, 0);
-    hbox1 = gtk_hbox_new (FALSE, 0);
-    hbox2 = gtk_hbox_new (FALSE, 0);
-    hbox3 = gtk_hbox_new (FALSE, 0);
-#endif
 
     focus_mode_checkbutton = gtk_check_button_new_with_mnemonic (_("_Select windows when the mouse moves over them"));
     gtk_box_pack_start (GTK_BOX (vbox), focus_mode_checkbutton, FALSE, FALSE, 6);
@@ -500,13 +455,9 @@ main (int argc, char **argv)
     gtk_box_pack_start (GTK_BOX (hbox2), autoraise_checkbutton, FALSE, FALSE, 6);
     gtk_box_pack_start (GTK_BOX (vbox1), hbox2, FALSE, FALSE, 6);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
     autoraise_delay_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
     autoraise_delay_slider = gtk_scale_new_with_range (GTK_ORIENTATION_HORIZONTAL, 0, 10, 0.2);
-#else
-    autoraise_delay_hbox = gtk_hbox_new (FALSE, 0);
-    autoraise_delay_slider = gtk_hscale_new_with_range (0, 10, 0.2);
-#endif
+
     widget = gtk_label_new_with_mnemonic (_("_Interval before raising:"));
     gtk_box_pack_start (GTK_BOX (autoraise_delay_hbox), widget, FALSE, FALSE, 6);
     gtk_box_pack_start (GTK_BOX (autoraise_delay_hbox), autoraise_delay_slider, TRUE, TRUE, 6);
@@ -525,11 +476,7 @@ main (int argc, char **argv)
     widget = title_label_new (N_("Titlebar Action"));
     gtk_box_pack_start (GTK_BOX (behaviour_vbox), widget, FALSE, FALSE, 6);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
     hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-#else
-    hbox = gtk_hbox_new (FALSE, 0);
-#endif
     widget = gtk_label_new_with_mnemonic (_("_Double-click titlebar to perform this action:"));
     gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 6);
     double_click_titlebar_optionmenu = gtk_combo_box_text_new ();
@@ -541,13 +488,8 @@ main (int argc, char **argv)
     widget = title_label_new (N_("Movement Key"));
     gtk_box_pack_start (GTK_BOX (behaviour_vbox), widget, FALSE, FALSE, 6);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
     vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-#else
-    vbox = gtk_vbox_new (FALSE, 0);
-    hbox = gtk_hbox_new (FALSE, 0);
-#endif
 
     widget = gtk_label_new_with_mnemonic (_("To move a window, press-and-hold this key then grab the window:"));
 #if GTK_CHECK_VERSION (3, 16, 0)
@@ -558,11 +500,7 @@ main (int argc, char **argv)
 #endif
     gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, FALSE, 6);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
     alt_click_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
-#else
-    alt_click_vbox = gtk_vbox_new (FALSE, 6);
-#endif
     gtk_label_set_mnemonic_widget (GTK_LABEL (widget), alt_click_vbox);
     gtk_box_pack_start (GTK_BOX (vbox), alt_click_vbox, FALSE, FALSE, 6);
     gtk_box_pack_start (GTK_BOX (hbox), vbox, FALSE, FALSE, 6);
