@@ -90,11 +90,7 @@ nld_search_bar_init (NldSearchBar * search_bar)
 	gtk_widget_set_can_focus (GTK_WIDGET (search_bar), TRUE);
 	gtk_orientable_set_orientation (GTK_ORIENTABLE (search_bar), GTK_ORIENTATION_VERTICAL);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 	priv->hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 3);
-#else
-	priv->hbox = gtk_hbox_new (FALSE, 3);
-#endif
 	gtk_box_pack_start (GTK_BOX (search_bar), priv->hbox, TRUE, FALSE, 0);
 
 	alignment = gtk_alignment_new (0.0, 0.5, 1.0, 0.0);
